from os import system
def vgratient(text,start,end):
    system(""); rgb = ""
    red = start[0]
    green = start[1]
    blue = start[2]
    redLast=end[0]
    greenLast=end[1]
    blueLast=end[2]
    lines=len(text.splitlines())
    redD=int((redLast-red)/lines)
    greenD=int((greenLast-green)/lines)
    blueD=int((blueLast-blue)/lines)
    for line in text.splitlines():
        rgb += (f"\033[38;2;{red};{green};{blue}m{line}\033[0m"+'\n')
        red = red + redD
        green=green+greenD
        blue=blue+blueD
    return rgb


from setuptools import setup, find_packages



setup(
    name='ab5',
    version='0.5',
    author="Ab.5#3363",
    author_email=None,
    description="print ascii art with gratient colors",
    long_description_content_type="text/markdown",
    long_description=open("README.md", encoding="utf-8").read(),
    url = "https://github.com/xxa2005/",
    keywords=['color', 'python', 'colors', 'cool', 'gratient', 'fade', 'shadow'],
    packages=["ab5"],
    classifiers=[
      "Intended Audience :: Developers",
      "Programming Language :: Python :: 3",
      "License :: OSI Approved :: MIT License",
      "Operating System :: OS Independent",
    ]
)